[dpdk-dev,v2,04/33] i40e/base: rename 'err' to 'perrno'

Message ID 1430406219-23901-5-git-send-email-helin.zhang@intel.com (mailing list archive)
State Accepted, archived
Headers

Commit Message

Zhang, Helin April 30, 2015, 3:03 p.m. UTC
  To be consistent with the original base driver, the variable name
of 'err' should be renamed to 'perrno'.

Signed-off-by: Helin Zhang <helin.zhang@intel.com>
---
 lib/librte_pmd_i40e/i40e/i40e_nvm.c | 118 ++++++++++++++++++------------------
 1 file changed, 59 insertions(+), 59 deletions(-)
  

Comments

Jingjing Wu May 8, 2015, 3:20 a.m. UTC | #1
Acked-by: Jingjing Wu <jingjing.wu@intel.com>

> -----Original Message-----
> From: Zhang, Helin
> Sent: Thursday, April 30, 2015 11:03 PM
> To: dev@dpdk.org
> Cc: Cao, Min; Xu, Qian Q; Wu, Jingjing; Liu, Jijiang; Kenguva, Monica; Patel,
> Rashmin N; Murray, Steven J; Nelson, Shannon; Zhang, Helin
> Subject: [PATCH v2 04/33] i40e/base: rename 'err' to 'perrno'
> 
> To be consistent with the original base driver, the variable name of 'err'
> should be renamed to 'perrno'.
> 
> Signed-off-by: Helin Zhang <helin.zhang@intel.com>
> ---
>  lib/librte_pmd_i40e/i40e/i40e_nvm.c | 118 ++++++++++++++++++------------
> ------
>  1 file changed, 59 insertions(+), 59 deletions(-)
> 
> diff --git a/lib/librte_pmd_i40e/i40e/i40e_nvm.c
> b/lib/librte_pmd_i40e/i40e/i40e_nvm.c
> index 73b8997..2b70508 100644
> --- a/lib/librte_pmd_i40e/i40e/i40e_nvm.c
> +++ b/lib/librte_pmd_i40e/i40e/i40e_nvm.c
> @@ -481,25 +481,25 @@ i40e_validate_nvm_checksum_exit:
> 
>  STATIC enum i40e_status_code i40e_nvmupd_state_init(struct i40e_hw
> *hw,
>  						    struct i40e_nvm_access
> *cmd,
> -						    u8 *bytes, int *err);
> +						    u8 *bytes, int *perrno);
>  STATIC enum i40e_status_code i40e_nvmupd_state_reading(struct i40e_hw
> *hw,
>  						    struct i40e_nvm_access
> *cmd,
> -						    u8 *bytes, int *err);
> +						    u8 *bytes, int *perrno);
>  STATIC enum i40e_status_code i40e_nvmupd_state_writing(struct i40e_hw
> *hw,
>  						    struct i40e_nvm_access
> *cmd,
> -						    u8 *bytes, int *err);
> +						    u8 *bytes, int *perrno);
>  STATIC enum i40e_nvmupd_cmd i40e_nvmupd_validate_command(struct
> i40e_hw *hw,
>  						    struct i40e_nvm_access
> *cmd,
> -						    int *err);
> +						    int *perrno);
>  STATIC enum i40e_status_code i40e_nvmupd_nvm_erase(struct i40e_hw
> *hw,
>  						   struct i40e_nvm_access
> *cmd,
> -						   int *err);
> +						   int *perrno);
>  STATIC enum i40e_status_code i40e_nvmupd_nvm_write(struct i40e_hw
> *hw,
>  						   struct i40e_nvm_access
> *cmd,
> -						   u8 *bytes, int *err);
> +						   u8 *bytes, int *perrno);
>  STATIC enum i40e_status_code i40e_nvmupd_nvm_read(struct i40e_hw
> *hw,
>  						  struct i40e_nvm_access
> *cmd,
> -						  u8 *bytes, int *err);
> +						  u8 *bytes, int *perrno);
>  STATIC inline u8 i40e_nvmupd_get_module(u32 val)  {
>  	return (u8)(val & I40E_NVM_MOD_PNT_MASK); @@ -514,38
> +514,38 @@ STATIC inline u8 i40e_nvmupd_get_transaction(u32 val)
>   * @hw: pointer to hardware structure
>   * @cmd: pointer to nvm update command
>   * @bytes: pointer to the data buffer
> - * @err: pointer to return error code
> + * @perrno: pointer to return error code
>   *
>   * Dispatches command depending on what update state is current
>   **/
>  enum i40e_status_code i40e_nvmupd_command(struct i40e_hw *hw,
>  					  struct i40e_nvm_access *cmd,
> -					  u8 *bytes, int *err)
> +					  u8 *bytes, int *perrno)
>  {
>  	enum i40e_status_code status;
> 
>  	DEBUGFUNC("i40e_nvmupd_command");
> 
>  	/* assume success */
> -	*err = 0;
> +	*perrno = 0;
> 
>  	switch (hw->nvmupd_state) {
>  	case I40E_NVMUPD_STATE_INIT:
> -		status = i40e_nvmupd_state_init(hw, cmd, bytes, err);
> +		status = i40e_nvmupd_state_init(hw, cmd, bytes, perrno);
>  		break;
> 
>  	case I40E_NVMUPD_STATE_READING:
> -		status = i40e_nvmupd_state_reading(hw, cmd, bytes, err);
> +		status = i40e_nvmupd_state_reading(hw, cmd, bytes,
> perrno);
>  		break;
> 
>  	case I40E_NVMUPD_STATE_WRITING:
> -		status = i40e_nvmupd_state_writing(hw, cmd, bytes, err);
> +		status = i40e_nvmupd_state_writing(hw, cmd, bytes, perrno);
>  		break;
> 
>  	default:
>  		/* invalid state, should never happen */
>  		status = I40E_NOT_SUPPORTED;
> -		*err = -ESRCH;
> +		*perrno = -ESRCH;
>  		break;
>  	}
>  	return status;
> @@ -556,29 +556,29 @@ enum i40e_status_code
> i40e_nvmupd_command(struct i40e_hw *hw,
>   * @hw: pointer to hardware structure
>   * @cmd: pointer to nvm update command buffer
>   * @bytes: pointer to the data buffer
> - * @err: pointer to return error code
> + * @perrno: pointer to return error code
>   *
>   * Process legitimate commands of the Init state and conditionally set next
>   * state. Reject all other commands.
>   **/
>  STATIC enum i40e_status_code i40e_nvmupd_state_init(struct i40e_hw
> *hw,
>  						    struct i40e_nvm_access
> *cmd,
> -						    u8 *bytes, int *err)
> +						    u8 *bytes, int *perrno)
>  {
>  	enum i40e_status_code status = I40E_SUCCESS;
>  	enum i40e_nvmupd_cmd upd_cmd;
> 
>  	DEBUGFUNC("i40e_nvmupd_state_init");
> 
> -	upd_cmd = i40e_nvmupd_validate_command(hw, cmd, err);
> +	upd_cmd = i40e_nvmupd_validate_command(hw, cmd, perrno);
> 
>  	switch (upd_cmd) {
>  	case I40E_NVMUPD_READ_SA:
>  		status = i40e_acquire_nvm(hw, I40E_RESOURCE_READ);
>  		if (status) {
> -			*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
> +			*perrno = i40e_aq_rc_to_posix(hw-
> >aq.asq_last_status);
>  		} else {
> -			status = i40e_nvmupd_nvm_read(hw, cmd, bytes,
> err);
> +			status = i40e_nvmupd_nvm_read(hw, cmd, bytes,
> perrno);
>  			i40e_release_nvm(hw);
>  		}
>  		break;
> @@ -586,9 +586,9 @@ STATIC enum i40e_status_code
> i40e_nvmupd_state_init(struct i40e_hw *hw,
>  	case I40E_NVMUPD_READ_SNT:
>  		status = i40e_acquire_nvm(hw, I40E_RESOURCE_READ);
>  		if (status) {
> -			*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
> +			*perrno = i40e_aq_rc_to_posix(hw-
> >aq.asq_last_status);
>  		} else {
> -			status = i40e_nvmupd_nvm_read(hw, cmd, bytes,
> err);
> +			status = i40e_nvmupd_nvm_read(hw, cmd, bytes,
> perrno);
>  			hw->nvmupd_state =
> I40E_NVMUPD_STATE_READING;
>  		}
>  		break;
> @@ -596,9 +596,9 @@ STATIC enum i40e_status_code
> i40e_nvmupd_state_init(struct i40e_hw *hw,
>  	case I40E_NVMUPD_WRITE_ERA:
>  		status = i40e_acquire_nvm(hw, I40E_RESOURCE_WRITE);
>  		if (status) {
> -			*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
> +			*perrno = i40e_aq_rc_to_posix(hw-
> >aq.asq_last_status);
>  		} else {
> -			status = i40e_nvmupd_nvm_erase(hw, cmd, err);
> +			status = i40e_nvmupd_nvm_erase(hw, cmd, perrno);
>  			if (status)
>  				i40e_release_nvm(hw);
>  			else
> @@ -609,9 +609,9 @@ STATIC enum i40e_status_code
> i40e_nvmupd_state_init(struct i40e_hw *hw,
>  	case I40E_NVMUPD_WRITE_SA:
>  		status = i40e_acquire_nvm(hw, I40E_RESOURCE_WRITE);
>  		if (status) {
> -			*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
> +			*perrno = i40e_aq_rc_to_posix(hw-
> >aq.asq_last_status);
>  		} else {
> -			status = i40e_nvmupd_nvm_write(hw, cmd, bytes,
> err);
> +			status = i40e_nvmupd_nvm_write(hw, cmd, bytes,
> perrno);
>  			if (status)
>  				i40e_release_nvm(hw);
>  			else
> @@ -622,9 +622,9 @@ STATIC enum i40e_status_code
> i40e_nvmupd_state_init(struct i40e_hw *hw,
>  	case I40E_NVMUPD_WRITE_SNT:
>  		status = i40e_acquire_nvm(hw, I40E_RESOURCE_WRITE);
>  		if (status) {
> -			*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
> +			*perrno = i40e_aq_rc_to_posix(hw-
> >aq.asq_last_status);
>  		} else {
> -			status = i40e_nvmupd_nvm_write(hw, cmd, bytes,
> err);
> +			status = i40e_nvmupd_nvm_write(hw, cmd, bytes,
> perrno);
>  			hw->nvmupd_state =
> I40E_NVMUPD_STATE_WRITING;
>  		}
>  		break;
> @@ -632,11 +632,11 @@ STATIC enum i40e_status_code
> i40e_nvmupd_state_init(struct i40e_hw *hw,
>  	case I40E_NVMUPD_CSUM_SA:
>  		status = i40e_acquire_nvm(hw, I40E_RESOURCE_WRITE);
>  		if (status) {
> -			*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
> +			*perrno = i40e_aq_rc_to_posix(hw-
> >aq.asq_last_status);
>  		} else {
>  			status = i40e_update_nvm_checksum(hw);
>  			if (status) {
> -				*err = hw->aq.asq_last_status ?
> +				*perrno = hw->aq.asq_last_status ?
>  				   i40e_aq_rc_to_posix(hw-
> >aq.asq_last_status) :
>  				   -EIO;
>  				i40e_release_nvm(hw);
> @@ -648,7 +648,7 @@ STATIC enum i40e_status_code
> i40e_nvmupd_state_init(struct i40e_hw *hw,
> 
>  	default:
>  		status = I40E_ERR_NVM;
> -		*err = -ESRCH;
> +		*perrno = -ESRCH;
>  		break;
>  	}
>  	return status;
> @@ -659,37 +659,37 @@ STATIC enum i40e_status_code
> i40e_nvmupd_state_init(struct i40e_hw *hw,
>   * @hw: pointer to hardware structure
>   * @cmd: pointer to nvm update command buffer
>   * @bytes: pointer to the data buffer
> - * @err: pointer to return error code
> + * @perrno: pointer to return error code
>   *
>   * NVM ownership is already held.  Process legitimate commands and set
> any
>   * change in state; reject all other commands.
>   **/
>  STATIC enum i40e_status_code i40e_nvmupd_state_reading(struct i40e_hw
> *hw,
>  						    struct i40e_nvm_access
> *cmd,
> -						    u8 *bytes, int *err)
> +						    u8 *bytes, int *perrno)
>  {
>  	enum i40e_status_code status;
>  	enum i40e_nvmupd_cmd upd_cmd;
> 
>  	DEBUGFUNC("i40e_nvmupd_state_reading");
> 
> -	upd_cmd = i40e_nvmupd_validate_command(hw, cmd, err);
> +	upd_cmd = i40e_nvmupd_validate_command(hw, cmd, perrno);
> 
>  	switch (upd_cmd) {
>  	case I40E_NVMUPD_READ_SA:
>  	case I40E_NVMUPD_READ_CON:
> -		status = i40e_nvmupd_nvm_read(hw, cmd, bytes, err);
> +		status = i40e_nvmupd_nvm_read(hw, cmd, bytes, perrno);
>  		break;
> 
>  	case I40E_NVMUPD_READ_LCB:
> -		status = i40e_nvmupd_nvm_read(hw, cmd, bytes, err);
> +		status = i40e_nvmupd_nvm_read(hw, cmd, bytes, perrno);
>  		i40e_release_nvm(hw);
>  		hw->nvmupd_state = I40E_NVMUPD_STATE_INIT;
>  		break;
> 
>  	default:
>  		status = I40E_NOT_SUPPORTED;
> -		*err = -ESRCH;
> +		*perrno = -ESRCH;
>  		break;
>  	}
>  	return status;
> @@ -700,29 +700,29 @@ STATIC enum i40e_status_code
> i40e_nvmupd_state_reading(struct i40e_hw *hw,
>   * @hw: pointer to hardware structure
>   * @cmd: pointer to nvm update command buffer
>   * @bytes: pointer to the data buffer
> - * @err: pointer to return error code
> + * @perrno: pointer to return error code
>   *
>   * NVM ownership is already held.  Process legitimate commands and set
> any
>   * change in state; reject all other commands
>   **/
>  STATIC enum i40e_status_code i40e_nvmupd_state_writing(struct i40e_hw
> *hw,
>  						    struct i40e_nvm_access
> *cmd,
> -						    u8 *bytes, int *err)
> +						    u8 *bytes, int *perrno)
>  {
>  	enum i40e_status_code status;
>  	enum i40e_nvmupd_cmd upd_cmd;
> 
>  	DEBUGFUNC("i40e_nvmupd_state_writing");
> 
> -	upd_cmd = i40e_nvmupd_validate_command(hw, cmd, err);
> +	upd_cmd = i40e_nvmupd_validate_command(hw, cmd, perrno);
> 
>  	switch (upd_cmd) {
>  	case I40E_NVMUPD_WRITE_CON:
> -		status = i40e_nvmupd_nvm_write(hw, cmd, bytes, err);
> +		status = i40e_nvmupd_nvm_write(hw, cmd, bytes, perrno);
>  		break;
> 
>  	case I40E_NVMUPD_WRITE_LCB:
> -		status = i40e_nvmupd_nvm_write(hw, cmd, bytes, err);
> +		status = i40e_nvmupd_nvm_write(hw, cmd, bytes, perrno);
>  		if (!status) {
>  			hw->aq.nvm_release_on_done = true;
>  			hw->nvmupd_state = I40E_NVMUPD_STATE_INIT;
> @@ -732,7 +732,7 @@ STATIC enum i40e_status_code
> i40e_nvmupd_state_writing(struct i40e_hw *hw,
>  	case I40E_NVMUPD_CSUM_CON:
>  		status = i40e_update_nvm_checksum(hw);
>  		if (status)
> -			*err = hw->aq.asq_last_status ?
> +			*perrno = hw->aq.asq_last_status ?
>  				   i40e_aq_rc_to_posix(hw-
> >aq.asq_last_status) :
>  				   -EIO;
>  		break;
> @@ -740,7 +740,7 @@ STATIC enum i40e_status_code
> i40e_nvmupd_state_writing(struct i40e_hw *hw,
>  	case I40E_NVMUPD_CSUM_LCB:
>  		status = i40e_update_nvm_checksum(hw);
>  		if (status) {
> -			*err = hw->aq.asq_last_status ?
> +			*perrno = hw->aq.asq_last_status ?
>  				   i40e_aq_rc_to_posix(hw-
> >aq.asq_last_status) :
>  				   -EIO;
>  		} else {
> @@ -751,7 +751,7 @@ STATIC enum i40e_status_code
> i40e_nvmupd_state_writing(struct i40e_hw *hw,
> 
>  	default:
>  		status = I40E_NOT_SUPPORTED;
> -		*err = -ESRCH;
> +		*perrno = -ESRCH;
>  		break;
>  	}
>  	return status;
> @@ -761,13 +761,13 @@ STATIC enum i40e_status_code
> i40e_nvmupd_state_writing(struct i40e_hw *hw,
>   * i40e_nvmupd_validate_command - Validate given command
>   * @hw: pointer to hardware structure
>   * @cmd: pointer to nvm update command buffer
> - * @err: pointer to return error code
> + * @perrno: pointer to return error code
>   *
>   * Return one of the valid command types or I40E_NVMUPD_INVALID
>   **/
>  STATIC enum i40e_nvmupd_cmd i40e_nvmupd_validate_command(struct
> i40e_hw *hw,
>  						    struct i40e_nvm_access
> *cmd,
> -						    int *err)
> +						    int *perrno)
>  {
>  	enum i40e_nvmupd_cmd upd_cmd;
>  	u8 transaction, module;
> @@ -785,7 +785,7 @@ STATIC enum i40e_nvmupd_cmd
> i40e_nvmupd_validate_command(struct i40e_hw *hw,
>  	    (cmd->data_size > I40E_NVMUPD_MAX_DATA)) {
>  		DEBUGOUT1("i40e_nvmupd_validate_command
> data_size %d\n",
>  			cmd->data_size);
> -		*err = -EFAULT;
> +		*perrno = -EFAULT;
>  		return I40E_NVMUPD_INVALID;
>  	}
> 
> @@ -838,10 +838,10 @@ STATIC enum i40e_nvmupd_cmd
> i40e_nvmupd_validate_command(struct i40e_hw *hw,
>  	}
> 
>  	if (upd_cmd == I40E_NVMUPD_INVALID) {
> -		*err = -EFAULT;
> +		*perrno = -EFAULT;
>  		DEBUGOUT2(
> -			"i40e_nvmupd_validate_command returns %d
> err: %d\n",
> -			upd_cmd, *err);
> +			"i40e_nvmupd_validate_command returns %d
> perrno: %d\n",
> +			upd_cmd, *perrno);
>  	}
>  	return upd_cmd;
>  }
> @@ -851,13 +851,13 @@ STATIC enum i40e_nvmupd_cmd
> i40e_nvmupd_validate_command(struct i40e_hw *hw,
>   * @hw: pointer to hardware structure
>   * @cmd: pointer to nvm update command buffer
>   * @bytes: pointer to the data buffer
> - * @err: pointer to return error code
> + * @perrno: pointer to return error code
>   *
>   * cmd structure contains identifiers and data buffer
>   **/
>  STATIC enum i40e_status_code i40e_nvmupd_nvm_read(struct i40e_hw
> *hw,
>  						  struct i40e_nvm_access
> *cmd,
> -						  u8 *bytes, int *err)
> +						  u8 *bytes, int *perrno)
>  {
>  	enum i40e_status_code status;
>  	u8 module, transaction;
> @@ -873,7 +873,7 @@ STATIC enum i40e_status_code
> i40e_nvmupd_nvm_read(struct i40e_hw *hw,
>  				  bytes, last, NULL);
>  	DEBUGOUT1("i40e_nvmupd_nvm_read status %d\n", status);
>  	if (status != I40E_SUCCESS)
> -		*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
> +		*perrno = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
> 
>  	return status;
>  }
> @@ -882,13 +882,13 @@ STATIC enum i40e_status_code
> i40e_nvmupd_nvm_read(struct i40e_hw *hw,
>   * i40e_nvmupd_nvm_erase - Erase an NVM module
>   * @hw: pointer to hardware structure
>   * @cmd: pointer to nvm update command buffer
> - * @err: pointer to return error code
> + * @perrno: pointer to return error code
>   *
>   * module, offset, data_size and data are in cmd structure
>   **/
>  STATIC enum i40e_status_code i40e_nvmupd_nvm_erase(struct i40e_hw
> *hw,
>  						   struct i40e_nvm_access
> *cmd,
> -						   int *err)
> +						   int *perrno)
>  {
>  	enum i40e_status_code status = I40E_SUCCESS;
>  	u8 module, transaction;
> @@ -903,7 +903,7 @@ STATIC enum i40e_status_code
> i40e_nvmupd_nvm_erase(struct i40e_hw *hw,
>  				   last, NULL);
>  	DEBUGOUT1("i40e_nvmupd_nvm_erase status %d\n", status);
>  	if (status != I40E_SUCCESS)
> -		*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
> +		*perrno = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
> 
>  	return status;
>  }
> @@ -913,13 +913,13 @@ STATIC enum i40e_status_code
> i40e_nvmupd_nvm_erase(struct i40e_hw *hw,
>   * @hw: pointer to hardware structure
>   * @cmd: pointer to nvm update command buffer
>   * @bytes: pointer to the data buffer
> - * @err: pointer to return error code
> + * @perrno: pointer to return error code
>   *
>   * module, offset, data_size and data are in cmd structure
>   **/
>  STATIC enum i40e_status_code i40e_nvmupd_nvm_write(struct i40e_hw
> *hw,
>  						   struct i40e_nvm_access
> *cmd,
> -						   u8 *bytes, int *err)
> +						   u8 *bytes, int *perrno)
>  {
>  	enum i40e_status_code status = I40E_SUCCESS;
>  	u8 module, transaction;
> @@ -934,7 +934,7 @@ STATIC enum i40e_status_code
> i40e_nvmupd_nvm_write(struct i40e_hw *hw,
>  				    (u16)cmd->data_size, bytes, last, NULL);
>  	DEBUGOUT1("i40e_nvmupd_nvm_write status %d\n", status);
>  	if (status != I40E_SUCCESS)
> -		*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
> +		*perrno = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
> 
>  	return status;
>  }
> --
> 1.8.1.4
  

Patch

diff --git a/lib/librte_pmd_i40e/i40e/i40e_nvm.c b/lib/librte_pmd_i40e/i40e/i40e_nvm.c
index 73b8997..2b70508 100644
--- a/lib/librte_pmd_i40e/i40e/i40e_nvm.c
+++ b/lib/librte_pmd_i40e/i40e/i40e_nvm.c
@@ -481,25 +481,25 @@  i40e_validate_nvm_checksum_exit:
 
 STATIC enum i40e_status_code i40e_nvmupd_state_init(struct i40e_hw *hw,
 						    struct i40e_nvm_access *cmd,
-						    u8 *bytes, int *err);
+						    u8 *bytes, int *perrno);
 STATIC enum i40e_status_code i40e_nvmupd_state_reading(struct i40e_hw *hw,
 						    struct i40e_nvm_access *cmd,
-						    u8 *bytes, int *err);
+						    u8 *bytes, int *perrno);
 STATIC enum i40e_status_code i40e_nvmupd_state_writing(struct i40e_hw *hw,
 						    struct i40e_nvm_access *cmd,
-						    u8 *bytes, int *err);
+						    u8 *bytes, int *perrno);
 STATIC enum i40e_nvmupd_cmd i40e_nvmupd_validate_command(struct i40e_hw *hw,
 						    struct i40e_nvm_access *cmd,
-						    int *err);
+						    int *perrno);
 STATIC enum i40e_status_code i40e_nvmupd_nvm_erase(struct i40e_hw *hw,
 						   struct i40e_nvm_access *cmd,
-						   int *err);
+						   int *perrno);
 STATIC enum i40e_status_code i40e_nvmupd_nvm_write(struct i40e_hw *hw,
 						   struct i40e_nvm_access *cmd,
-						   u8 *bytes, int *err);
+						   u8 *bytes, int *perrno);
 STATIC enum i40e_status_code i40e_nvmupd_nvm_read(struct i40e_hw *hw,
 						  struct i40e_nvm_access *cmd,
-						  u8 *bytes, int *err);
+						  u8 *bytes, int *perrno);
 STATIC inline u8 i40e_nvmupd_get_module(u32 val)
 {
 	return (u8)(val & I40E_NVM_MOD_PNT_MASK);
@@ -514,38 +514,38 @@  STATIC inline u8 i40e_nvmupd_get_transaction(u32 val)
  * @hw: pointer to hardware structure
  * @cmd: pointer to nvm update command
  * @bytes: pointer to the data buffer
  * @err: pointer to return error code
  *
  * Dispatches command depending on what update state is current
  **/
 enum i40e_status_code i40e_nvmupd_command(struct i40e_hw *hw,
 					  struct i40e_nvm_access *cmd,
-					  u8 *bytes, int *err)
+					  u8 *bytes, int *perrno)
 {
 	enum i40e_status_code status;
 
 	DEBUGFUNC("i40e_nvmupd_command");
 
 	/* assume success */
-	*err = 0;
+	*perrno = 0;
 
 	switch (hw->nvmupd_state) {
 	case I40E_NVMUPD_STATE_INIT:
-		status = i40e_nvmupd_state_init(hw, cmd, bytes, err);
+		status = i40e_nvmupd_state_init(hw, cmd, bytes, perrno);
 		break;
 
 	case I40E_NVMUPD_STATE_READING:
-		status = i40e_nvmupd_state_reading(hw, cmd, bytes, err);
+		status = i40e_nvmupd_state_reading(hw, cmd, bytes, perrno);
 		break;
 
 	case I40E_NVMUPD_STATE_WRITING:
-		status = i40e_nvmupd_state_writing(hw, cmd, bytes, err);
+		status = i40e_nvmupd_state_writing(hw, cmd, bytes, perrno);
 		break;
 
 	default:
 		/* invalid state, should never happen */
 		status = I40E_NOT_SUPPORTED;
-		*err = -ESRCH;
+		*perrno = -ESRCH;
 		break;
 	}
 	return status;
@@ -556,29 +556,29 @@  enum i40e_status_code i40e_nvmupd_command(struct i40e_hw *hw,
  * @hw: pointer to hardware structure
  * @cmd: pointer to nvm update command buffer
  * @bytes: pointer to the data buffer
  * @err: pointer to return error code
  *
  * Process legitimate commands of the Init state and conditionally set next
  * state. Reject all other commands.
  **/
 STATIC enum i40e_status_code i40e_nvmupd_state_init(struct i40e_hw *hw,
 						    struct i40e_nvm_access *cmd,
-						    u8 *bytes, int *err)
+						    u8 *bytes, int *perrno)
 {
 	enum i40e_status_code status = I40E_SUCCESS;
 	enum i40e_nvmupd_cmd upd_cmd;
 
 	DEBUGFUNC("i40e_nvmupd_state_init");
 
-	upd_cmd = i40e_nvmupd_validate_command(hw, cmd, err);
+	upd_cmd = i40e_nvmupd_validate_command(hw, cmd, perrno);
 
 	switch (upd_cmd) {
 	case I40E_NVMUPD_READ_SA:
 		status = i40e_acquire_nvm(hw, I40E_RESOURCE_READ);
 		if (status) {
-			*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
+			*perrno = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
 		} else {
-			status = i40e_nvmupd_nvm_read(hw, cmd, bytes, err);
+			status = i40e_nvmupd_nvm_read(hw, cmd, bytes, perrno);
 			i40e_release_nvm(hw);
 		}
 		break;
@@ -586,9 +586,9 @@  STATIC enum i40e_status_code i40e_nvmupd_state_init(struct i40e_hw *hw,
 	case I40E_NVMUPD_READ_SNT:
 		status = i40e_acquire_nvm(hw, I40E_RESOURCE_READ);
 		if (status) {
-			*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
+			*perrno = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
 		} else {
-			status = i40e_nvmupd_nvm_read(hw, cmd, bytes, err);
+			status = i40e_nvmupd_nvm_read(hw, cmd, bytes, perrno);
 			hw->nvmupd_state = I40E_NVMUPD_STATE_READING;
 		}
 		break;
@@ -596,9 +596,9 @@  STATIC enum i40e_status_code i40e_nvmupd_state_init(struct i40e_hw *hw,
 	case I40E_NVMUPD_WRITE_ERA:
 		status = i40e_acquire_nvm(hw, I40E_RESOURCE_WRITE);
 		if (status) {
-			*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
+			*perrno = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
 		} else {
-			status = i40e_nvmupd_nvm_erase(hw, cmd, err);
+			status = i40e_nvmupd_nvm_erase(hw, cmd, perrno);
 			if (status)
 				i40e_release_nvm(hw);
 			else
@@ -609,9 +609,9 @@  STATIC enum i40e_status_code i40e_nvmupd_state_init(struct i40e_hw *hw,
 	case I40E_NVMUPD_WRITE_SA:
 		status = i40e_acquire_nvm(hw, I40E_RESOURCE_WRITE);
 		if (status) {
-			*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
+			*perrno = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
 		} else {
-			status = i40e_nvmupd_nvm_write(hw, cmd, bytes, err);
+			status = i40e_nvmupd_nvm_write(hw, cmd, bytes, perrno);
 			if (status)
 				i40e_release_nvm(hw);
 			else
@@ -622,9 +622,9 @@  STATIC enum i40e_status_code i40e_nvmupd_state_init(struct i40e_hw *hw,
 	case I40E_NVMUPD_WRITE_SNT:
 		status = i40e_acquire_nvm(hw, I40E_RESOURCE_WRITE);
 		if (status) {
-			*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
+			*perrno = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
 		} else {
-			status = i40e_nvmupd_nvm_write(hw, cmd, bytes, err);
+			status = i40e_nvmupd_nvm_write(hw, cmd, bytes, perrno);
 			hw->nvmupd_state = I40E_NVMUPD_STATE_WRITING;
 		}
 		break;
@@ -632,11 +632,11 @@  STATIC enum i40e_status_code i40e_nvmupd_state_init(struct i40e_hw *hw,
 	case I40E_NVMUPD_CSUM_SA:
 		status = i40e_acquire_nvm(hw, I40E_RESOURCE_WRITE);
 		if (status) {
-			*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
+			*perrno = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
 		} else {
 			status = i40e_update_nvm_checksum(hw);
 			if (status) {
-				*err = hw->aq.asq_last_status ?
+				*perrno = hw->aq.asq_last_status ?
 				   i40e_aq_rc_to_posix(hw->aq.asq_last_status) :
 				   -EIO;
 				i40e_release_nvm(hw);
@@ -648,7 +648,7 @@  STATIC enum i40e_status_code i40e_nvmupd_state_init(struct i40e_hw *hw,
 
 	default:
 		status = I40E_ERR_NVM;
-		*err = -ESRCH;
+		*perrno = -ESRCH;
 		break;
 	}
 	return status;
@@ -659,37 +659,37 @@  STATIC enum i40e_status_code i40e_nvmupd_state_init(struct i40e_hw *hw,
  * @hw: pointer to hardware structure
  * @cmd: pointer to nvm update command buffer
  * @bytes: pointer to the data buffer
  * @err: pointer to return error code
  *
  * NVM ownership is already held.  Process legitimate commands and set any
  * change in state; reject all other commands.
  **/
 STATIC enum i40e_status_code i40e_nvmupd_state_reading(struct i40e_hw *hw,
 						    struct i40e_nvm_access *cmd,
-						    u8 *bytes, int *err)
+						    u8 *bytes, int *perrno)
 {
 	enum i40e_status_code status;
 	enum i40e_nvmupd_cmd upd_cmd;
 
 	DEBUGFUNC("i40e_nvmupd_state_reading");
 
-	upd_cmd = i40e_nvmupd_validate_command(hw, cmd, err);
+	upd_cmd = i40e_nvmupd_validate_command(hw, cmd, perrno);
 
 	switch (upd_cmd) {
 	case I40E_NVMUPD_READ_SA:
 	case I40E_NVMUPD_READ_CON:
-		status = i40e_nvmupd_nvm_read(hw, cmd, bytes, err);
+		status = i40e_nvmupd_nvm_read(hw, cmd, bytes, perrno);
 		break;
 
 	case I40E_NVMUPD_READ_LCB:
-		status = i40e_nvmupd_nvm_read(hw, cmd, bytes, err);
+		status = i40e_nvmupd_nvm_read(hw, cmd, bytes, perrno);
 		i40e_release_nvm(hw);
 		hw->nvmupd_state = I40E_NVMUPD_STATE_INIT;
 		break;
 
 	default:
 		status = I40E_NOT_SUPPORTED;
-		*err = -ESRCH;
+		*perrno = -ESRCH;
 		break;
 	}
 	return status;
@@ -700,29 +700,29 @@  STATIC enum i40e_status_code i40e_nvmupd_state_reading(struct i40e_hw *hw,
  * @hw: pointer to hardware structure
  * @cmd: pointer to nvm update command buffer
  * @bytes: pointer to the data buffer
  * @err: pointer to return error code
  *
  * NVM ownership is already held.  Process legitimate commands and set any
  * change in state; reject all other commands
  **/
 STATIC enum i40e_status_code i40e_nvmupd_state_writing(struct i40e_hw *hw,
 						    struct i40e_nvm_access *cmd,
-						    u8 *bytes, int *err)
+						    u8 *bytes, int *perrno)
 {
 	enum i40e_status_code status;
 	enum i40e_nvmupd_cmd upd_cmd;
 
 	DEBUGFUNC("i40e_nvmupd_state_writing");
 
-	upd_cmd = i40e_nvmupd_validate_command(hw, cmd, err);
+	upd_cmd = i40e_nvmupd_validate_command(hw, cmd, perrno);
 
 	switch (upd_cmd) {
 	case I40E_NVMUPD_WRITE_CON:
-		status = i40e_nvmupd_nvm_write(hw, cmd, bytes, err);
+		status = i40e_nvmupd_nvm_write(hw, cmd, bytes, perrno);
 		break;
 
 	case I40E_NVMUPD_WRITE_LCB:
-		status = i40e_nvmupd_nvm_write(hw, cmd, bytes, err);
+		status = i40e_nvmupd_nvm_write(hw, cmd, bytes, perrno);
 		if (!status) {
 			hw->aq.nvm_release_on_done = true;
 			hw->nvmupd_state = I40E_NVMUPD_STATE_INIT;
@@ -732,7 +732,7 @@  STATIC enum i40e_status_code i40e_nvmupd_state_writing(struct i40e_hw *hw,
 	case I40E_NVMUPD_CSUM_CON:
 		status = i40e_update_nvm_checksum(hw);
 		if (status)
-			*err = hw->aq.asq_last_status ?
+			*perrno = hw->aq.asq_last_status ?
 				   i40e_aq_rc_to_posix(hw->aq.asq_last_status) :
 				   -EIO;
 		break;
@@ -740,7 +740,7 @@  STATIC enum i40e_status_code i40e_nvmupd_state_writing(struct i40e_hw *hw,
 	case I40E_NVMUPD_CSUM_LCB:
 		status = i40e_update_nvm_checksum(hw);
 		if (status) {
-			*err = hw->aq.asq_last_status ?
+			*perrno = hw->aq.asq_last_status ?
 				   i40e_aq_rc_to_posix(hw->aq.asq_last_status) :
 				   -EIO;
 		} else {
@@ -751,7 +751,7 @@  STATIC enum i40e_status_code i40e_nvmupd_state_writing(struct i40e_hw *hw,
 
 	default:
 		status = I40E_NOT_SUPPORTED;
-		*err = -ESRCH;
+		*perrno = -ESRCH;
 		break;
 	}
 	return status;
@@ -761,13 +761,13 @@  STATIC enum i40e_status_code i40e_nvmupd_state_writing(struct i40e_hw *hw,
  * i40e_nvmupd_validate_command - Validate given command
  * @hw: pointer to hardware structure
  * @cmd: pointer to nvm update command buffer
  * @err: pointer to return error code
  *
  * Return one of the valid command types or I40E_NVMUPD_INVALID
  **/
 STATIC enum i40e_nvmupd_cmd i40e_nvmupd_validate_command(struct i40e_hw *hw,
 						    struct i40e_nvm_access *cmd,
-						    int *err)
+						    int *perrno)
 {
 	enum i40e_nvmupd_cmd upd_cmd;
 	u8 transaction, module;
@@ -785,7 +785,7 @@  STATIC enum i40e_nvmupd_cmd i40e_nvmupd_validate_command(struct i40e_hw *hw,
 	    (cmd->data_size > I40E_NVMUPD_MAX_DATA)) {
 		DEBUGOUT1("i40e_nvmupd_validate_command data_size %d\n",
 			cmd->data_size);
-		*err = -EFAULT;
+		*perrno = -EFAULT;
 		return I40E_NVMUPD_INVALID;
 	}
 
@@ -838,10 +838,10 @@  STATIC enum i40e_nvmupd_cmd i40e_nvmupd_validate_command(struct i40e_hw *hw,
 	}
 
 	if (upd_cmd == I40E_NVMUPD_INVALID) {
-		*err = -EFAULT;
+		*perrno = -EFAULT;
 		DEBUGOUT2(
-			"i40e_nvmupd_validate_command returns %d  err: %d\n",
-			upd_cmd, *err);
+			"i40e_nvmupd_validate_command returns %d  perrno: %d\n",
+			upd_cmd, *perrno);
 	}
 	return upd_cmd;
 }
@@ -851,13 +851,13 @@  STATIC enum i40e_nvmupd_cmd i40e_nvmupd_validate_command(struct i40e_hw *hw,
  * @hw: pointer to hardware structure
  * @cmd: pointer to nvm update command buffer
  * @bytes: pointer to the data buffer
  * @err: pointer to return error code
  *
  * cmd structure contains identifiers and data buffer
  **/
 STATIC enum i40e_status_code i40e_nvmupd_nvm_read(struct i40e_hw *hw,
 						  struct i40e_nvm_access *cmd,
-						  u8 *bytes, int *err)
+						  u8 *bytes, int *perrno)
 {
 	enum i40e_status_code status;
 	u8 module, transaction;
@@ -873,7 +873,7 @@  STATIC enum i40e_status_code i40e_nvmupd_nvm_read(struct i40e_hw *hw,
 				  bytes, last, NULL);
 	DEBUGOUT1("i40e_nvmupd_nvm_read status %d\n", status);
 	if (status != I40E_SUCCESS)
-		*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
+		*perrno = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
 
 	return status;
 }
@@ -882,13 +882,13 @@  STATIC enum i40e_status_code i40e_nvmupd_nvm_read(struct i40e_hw *hw,
  * i40e_nvmupd_nvm_erase - Erase an NVM module
  * @hw: pointer to hardware structure
  * @cmd: pointer to nvm update command buffer
  * @err: pointer to return error code
  *
  * module, offset, data_size and data are in cmd structure
  **/
 STATIC enum i40e_status_code i40e_nvmupd_nvm_erase(struct i40e_hw *hw,
 						   struct i40e_nvm_access *cmd,
-						   int *err)
+						   int *perrno)
 {
 	enum i40e_status_code status = I40E_SUCCESS;
 	u8 module, transaction;
@@ -903,7 +903,7 @@  STATIC enum i40e_status_code i40e_nvmupd_nvm_erase(struct i40e_hw *hw,
 				   last, NULL);
 	DEBUGOUT1("i40e_nvmupd_nvm_erase status %d\n", status);
 	if (status != I40E_SUCCESS)
-		*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
+		*perrno = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
 
 	return status;
 }
@@ -913,13 +913,13 @@  STATIC enum i40e_status_code i40e_nvmupd_nvm_erase(struct i40e_hw *hw,
  * @hw: pointer to hardware structure
  * @cmd: pointer to nvm update command buffer
  * @bytes: pointer to the data buffer
  * @err: pointer to return error code
  *
  * module, offset, data_size and data are in cmd structure
  **/
 STATIC enum i40e_status_code i40e_nvmupd_nvm_write(struct i40e_hw *hw,
 						   struct i40e_nvm_access *cmd,
-						   u8 *bytes, int *err)
+						   u8 *bytes, int *perrno)
 {
 	enum i40e_status_code status = I40E_SUCCESS;
 	u8 module, transaction;
@@ -934,7 +934,7 @@  STATIC enum i40e_status_code i40e_nvmupd_nvm_write(struct i40e_hw *hw,
 				    (u16)cmd->data_size, bytes, last, NULL);
 	DEBUGOUT1("i40e_nvmupd_nvm_write status %d\n", status);
 	if (status != I40E_SUCCESS)
-		*err = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
+		*perrno = i40e_aq_rc_to_posix(hw->aq.asq_last_status);
 
 	return status;
 }
@@ -514,38 +514,38 @@  STATIC inline u8 i40e_nvmupd_get_transaction(u32 val)
  * @cmd: pointer to nvm update command
  * @bytes: pointer to the data buffer
- * @err: pointer to return error code
+ * @perrno: pointer to return error code
  *
  * Dispatches command depending on what update state is current
@@ -556,29 +556,29 @@  enum i40e_status_code i40e_nvmupd_command(struct i40e_hw *hw,
  * @cmd: pointer to nvm update command buffer
  * @bytes: pointer to the data buffer
- * @err: pointer to return error code
+ * @perrno: pointer to return error code
  *
  * Process legitimate commands of the Init state and conditionally set next
@@ -659,37 +659,37 @@  STATIC enum i40e_status_code i40e_nvmupd_state_init(struct i40e_hw *hw,
  * @cmd: pointer to nvm update command buffer
  * @bytes: pointer to the data buffer
- * @err: pointer to return error code
+ * @perrno: pointer to return error code
  *
  * NVM ownership is already held.  Process legitimate commands and set any
@@ -700,29 +700,29 @@  STATIC enum i40e_status_code i40e_nvmupd_state_reading(struct i40e_hw *hw,
  * @cmd: pointer to nvm update command buffer
  * @bytes: pointer to the data buffer
- * @err: pointer to return error code
+ * @perrno: pointer to return error code
  *
  * NVM ownership is already held.  Process legitimate commands and set any
@@ -761,13 +761,13 @@  STATIC enum i40e_status_code i40e_nvmupd_state_writing(struct i40e_hw *hw,
  * @hw: pointer to hardware structure
  * @cmd: pointer to nvm update command buffer
- * @err: pointer to return error code
+ * @perrno: pointer to return error code
  *
  * Return one of the valid command types or I40E_NVMUPD_INVALID
@@ -851,13 +851,13 @@  STATIC enum i40e_nvmupd_cmd i40e_nvmupd_validate_command(struct i40e_hw *hw,
  * @cmd: pointer to nvm update command buffer
  * @bytes: pointer to the data buffer
- * @err: pointer to return error code
+ * @perrno: pointer to return error code
  *
  * cmd structure contains identifiers and data buffer
@@ -882,13 +882,13 @@  STATIC enum i40e_status_code i40e_nvmupd_nvm_read(struct i40e_hw *hw,
  * @hw: pointer to hardware structure
  * @cmd: pointer to nvm update command buffer
- * @err: pointer to return error code
+ * @perrno: pointer to return error code
  *
  * module, offset, data_size and data are in cmd structure
@@ -913,13 +913,13 @@  STATIC enum i40e_status_code i40e_nvmupd_nvm_erase(struct i40e_hw *hw,
  * @cmd: pointer to nvm update command buffer
  * @bytes: pointer to the data buffer
- * @err: pointer to return error code
+ * @perrno: pointer to return error code
  *
  * module, offset, data_size and data are in cmd structure